==> haskell-yesod-test-1.5.9.1-32-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-yesod-test.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yesod-test
version: 1.5.9.1
id: yesod-test-1.5.9.1-Cof1kAIvT118bM6Dj5duUK
key: yesod-test-1.5.9.1-Cof1kAIvT118bM6Dj5duUK
license: MIT
maintainer: Michael Snoyman, Greg Weber, Nubis <nubis@woobiz.com.ar>
stability: Experimental
homepage: http://www.yesodweb.com
synopsis: integration testing for WAI/Yesod Applications
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-test>
category: Web, Yesod, Testing
author: Nubis <nubis@woobiz.com.ar>
exposed: True
indefinite: False
exposed-modules:
    Yesod.Test Yesod.Test.CssQuery Yesod.Test.TransversingCSS
abi: cc8c8607f94be621c489512ab5730757
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/yesod-test-1.5.9.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/yesod-test-1.5.9.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/yesod-test-1.5.9.1
hs-libraries: HSyesod-test-1.5.9.1-Cof1kAIvT118bM6Dj5duUK
depends:
    HUnit-1.6.0.0-AX6otQL79amDimk89yA6v4
    attoparsec-0.13.2.2-1IsPw46SBaXMxKqrmF8MV base-4.10.1.0
    blaze-builder-0.4.0.2-DHYoGQYzHva8PydFQisCY7
    blaze-html-0.9.0.1-2Wxj0X1c4OOA0Fs6NGHGGN
    blaze-markup-0.8.2.0-JO1Oy9jYgbGFSxqAItqjWc bytestring-0.10.8.2
    case-insensitive-1.2.0.10-AWseT79MXu13ZYpcQBCANd
    containers-0.5.10.2 cookie-0.4.3-BpXx98lTuQn4TrJzMmRr4c
    hspec-core-2.4.7-BdO7uKAM0Ee9jQLy4iXSiZ
    html-conduit-1.2.1.2-A5BBWxN9wtyDyJryzYznkm
    http-types-0.9.1-4ZIPDJugy3GJAtyWZ0RpKv
    monad-control-1.0.2.2-Cf7Y7IL4PGG7qLiejghsYv
    network-2.6.3.3-BsPhUcUvmHlbFKWY24Oor
    persistent-2.7.3.1-2yQHX8opaiXJroVcoaNB4L
    pretty-show-1.6.16-4yL3QMm4omX5sydQq6eqFv
    text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj time-1.8.0.2
    transformers-0.5.2.0 wai-3.2.1.1-12WuVnNjQfQ3f2A19Ra0dE
    wai-extra-3.0.22.0-KxjpAZh0A1v4YCDGlrTuD7
    xml-conduit-1.7.1.2-4XQaMt2BDbhLDuJYGeIOTt
    xml-types-0.3.6-8U94ZZax169GYLVDpT1mig
    yesod-core-1.4.37.3-JhfyV2GdDZKMGdOjnhrxw
abi-depends: HUnit-1.6.0.0-AX6otQL79amDimk89yA6v4=cc02d4bbc4678b779cddf8743bb71eea
             attoparsec-0.13.2.2-1IsPw46SBaXMxKqrmF8MV=c494333baf54c0b8596ba018ce99c526
             base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             blaze-builder-0.4.0.2-DHYoGQYzHva8PydFQisCY7=4ded867b3c298ec132dad2104a7f7b70
             blaze-html-0.9.0.1-2Wxj0X1c4OOA0Fs6NGHGGN=d4749ddd32d1bff43101b58ffdfa6b64
             blaze-markup-0.8.2.0-JO1Oy9jYgbGFSxqAItqjWc=8e9b9ff2cdf9e89a23593b7f85e59200
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             case-insensitive-1.2.0.10-AWseT79MXu13ZYpcQBCANd=d2a631059bf8ed4631eaacfed742cab7
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             cookie-0.4.3-BpXx98lTuQn4TrJzMmRr4c=0bf41c1786cd0a8175b285dc559a180c
             hspec-core-2.4.7-BdO7uKAM0Ee9jQLy4iXSiZ=d587e84fc35c1ec474c41ba2be7f8b8e
             html-conduit-1.2.1.2-A5BBWxN9wtyDyJryzYznkm=55cac3893e1d65f91b9d6ff5e0fe9572
             http-types-0.9.1-4ZIPDJugy3GJAtyWZ0RpKv=b80836ab18bdd54a07dfb2450d10ef5b
             monad-control-1.0.2.2-Cf7Y7IL4PGG7qLiejghsYv=4ed72a305de1efe6a7bffe480e981599
             network-2.6.3.3-BsPhUcUvmHlbFKWY24Oor=f013b5448241bfbc78fb9f4b90b2582b
             persistent-2.7.3.1-2yQHX8opaiXJroVcoaNB4L=34b730baa12818c7b83171d5166e70f6
             pretty-show-1.6.16-4yL3QMm4omX5sydQq6eqFv=a68af35cb8ebe4069d7cae43e78dc845
             text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj=b7726d921cac66adc5c8f9f66f5b25f0
             time-1.8.0.2=d7392e85059cb108aeb68d6e24815970
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
             wai-3.2.1.1-12WuVnNjQfQ3f2A19Ra0dE=73d1afed3c80663ac957a99a7f1e4642
             wai-extra-3.0.22.0-KxjpAZh0A1v4YCDGlrTuD7=593b2bd9429ba7f2d96bae19aa33b8f4
             xml-conduit-1.7.1.2-4XQaMt2BDbhLDuJYGeIOTt=d9e63ee5aade064c81da611fb74c29ae
             xml-types-0.3.6-8U94ZZax169GYLVDpT1mig=d5c752ba65b163e7bdddd7a60950098d
             yesod-core-1.4.37.3-JhfyV2GdDZKMGdOjnhrxw=33092198d0dbca667c209c5448d6b456
haddock-interfaces: /usr/share/doc/haskell-yesod-test/html/yesod-test.haddock
haddock-html: /usr/share/doc/haskell-yesod-test/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-yesod-test-1.5.9.1-46-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-yesod-test.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yesod-test
version: 1.5.9.1
id: yesod-test-1.5.9.1-FJyyD6SsX8VHIYFJEtrgnr
key: yesod-test-1.5.9.1-FJyyD6SsX8VHIYFJEtrgnr
license: MIT
maintainer: Michael Snoyman, Greg Weber, Nubis <nubis@woobiz.com.ar>
stability: Experimental
homepage: http://www.yesodweb.com
synopsis: integration testing for WAI/Yesod Applications
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-test>
category: Web, Yesod, Testing
author: Nubis <nubis@woobiz.com.ar>
exposed: True
indefinite: False
exposed-modules:
    Yesod.Test Yesod.Test.CssQuery Yesod.Test.TransversingCSS
abi: 77dca33ebf37771a60b5c7482b89e643
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/yesod-test-1.5.9.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/yesod-test-1.5.9.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/yesod-test-1.5.9.1
hs-libraries: HSyesod-test-1.5.9.1-FJyyD6SsX8VHIYFJEtrgnr
depends:
    HUnit-1.6.0.0-AX6otQL79amDimk89yA6v4
    attoparsec-0.13.2.2-6Afec3PTeJ8I3cxSKL61mm base-4.10.1.0
    blaze-builder-0.4.0.2-DHYoGQYzHva8PydFQisCY7
    blaze-html-0.9.0.1-2Wxj0X1c4OOA0Fs6NGHGGN
    blaze-markup-0.8.2.0-JO1Oy9jYgbGFSxqAItqjWc bytestring-0.10.8.2
    case-insensitive-1.2.0.10-AWseT79MXu13ZYpcQBCANd
    containers-0.5.10.2 cookie-0.4.3-BpXx98lTuQn4TrJzMmRr4c
    hspec-core-2.4.7-BdO7uKAM0Ee9jQLy4iXSiZ
    html-conduit-1.2.1.2-7a0MTnZ3Z60I5fhVdEbNir
    http-types-0.9.1-4ZIPDJugy3GJAtyWZ0RpKv
    monad-control-1.0.2.2-Cf7Y7IL4PGG7qLiejghsYv
    network-2.6.3.3-BLvpugKNYUSFzAKouqFcFM
    persistent-2.7.3.1-6IPJfmQxrAM2v1XHnbLURw
    pretty-show-1.6.16-4yL3QMm4omX5sydQq6eqFv
    text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj time-1.8.0.2
    transformers-0.5.2.0 wai-3.2.1.1-FFdyPRpWxQ97tBGJ3Vieeo
    wai-extra-3.0.22.0-AfHfrPNf7re3OegGdNW1bl
    xml-conduit-1.7.1.2-EL0PNOjQVAlGLxGzw5Jnsy
    xml-types-0.3.6-8U94ZZax169GYLVDpT1mig
    yesod-core-1.4.37.3-Kpxc0d7LmKrBamG0ICPMei
abi-depends: HUnit-1.6.0.0-AX6otQL79amDimk89yA6v4=cc02d4bbc4678b779cddf8743bb71eea
             attoparsec-0.13.2.2-6Afec3PTeJ8I3cxSKL61mm=dbf2a2c6556965dad88a2349e873212b
             base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             blaze-builder-0.4.0.2-DHYoGQYzHva8PydFQisCY7=4ded867b3c298ec132dad2104a7f7b70
             blaze-html-0.9.0.1-2Wxj0X1c4OOA0Fs6NGHGGN=d4749ddd32d1bff43101b58ffdfa6b64
             blaze-markup-0.8.2.0-JO1Oy9jYgbGFSxqAItqjWc=8e9b9ff2cdf9e89a23593b7f85e59200
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             case-insensitive-1.2.0.10-AWseT79MXu13ZYpcQBCANd=d2a631059bf8ed4631eaacfed742cab7
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             cookie-0.4.3-BpXx98lTuQn4TrJzMmRr4c=0bf41c1786cd0a8175b285dc559a180c
             hspec-core-2.4.7-BdO7uKAM0Ee9jQLy4iXSiZ=d587e84fc35c1ec474c41ba2be7f8b8e
             html-conduit-1.2.1.2-7a0MTnZ3Z60I5fhVdEbNir=39dc61422c6add0475684be219786634
             http-types-0.9.1-4ZIPDJugy3GJAtyWZ0RpKv=b80836ab18bdd54a07dfb2450d10ef5b
             monad-control-1.0.2.2-Cf7Y7IL4PGG7qLiejghsYv=4ed72a305de1efe6a7bffe480e981599
             network-2.6.3.3-BLvpugKNYUSFzAKouqFcFM=58be2fae16c0eb05685e5ecea6703cff
             persistent-2.7.3.1-6IPJfmQxrAM2v1XHnbLURw=6353032350dd62a1bc688da3655d0d71
             pretty-show-1.6.16-4yL3QMm4omX5sydQq6eqFv=a68af35cb8ebe4069d7cae43e78dc845
             text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj=b7726d921cac66adc5c8f9f66f5b25f0
             time-1.8.0.2=d7392e85059cb108aeb68d6e24815970
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
             wai-3.2.1.1-FFdyPRpWxQ97tBGJ3Vieeo=f23fc7107acf0017818154e8027ca65c
             wai-extra-3.0.22.0-AfHfrPNf7re3OegGdNW1bl=66bb6023bd1c2bcaf973512713d14835
             xml-conduit-1.7.1.2-EL0PNOjQVAlGLxGzw5Jnsy=996077a8462dd74ab7227d6172a6dcee
             xml-types-0.3.6-8U94ZZax169GYLVDpT1mig=d5c752ba65b163e7bdddd7a60950098d
             yesod-core-1.4.37.3-Kpxc0d7LmKrBamG0ICPMei=9e9830e108be6484da698a6cd1df67be
haddock-interfaces: /usr/share/doc/haskell-yesod-test/html/yesod-test.haddock
haddock-html: /usr/share/doc/haskell-yesod-test/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
